summaryrefslogtreecommitdiffstats
path: root/kmail/configuredialog.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 06:08:18 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 06:08:18 +0000
commit4c6f8d69e2d1501837affb472c4eb8fec4462240 (patch)
tree766a8ad7939fcf3eec534184c36bd0e0f80489e2 /kmail/configuredialog.cpp
parent469cc56a805bd3d6940d54adbef554877c29853c (diff)
downloadtdepim-4c6f8d69e2d1501837affb472c4eb8fec4462240.tar.gz
tdepim-4c6f8d69e2d1501837affb472c4eb8fec4462240.zip
rename the following methods:
tqfind find tqreplace replace tqcontains contains git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1246075 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kmail/configuredialog.cpp')
-rw-r--r--kmail/configuredialog.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/kmail/configuredialog.cpp b/kmail/configuredialog.cpp
index e1fa0898..c0d775cf 100644
--- a/kmail/configuredialog.cpp
+++ b/kmail/configuredialog.cpp
@@ -480,7 +480,7 @@ void IdentityPage::slotRenameIdentity( TQListViewItem * i,
TQString newName = s.stripWhiteSpace();
if ( !newName.isEmpty() &&
- !kmkernel->identityManager()->shadowIdentities().tqcontains( newName ) ) {
+ !kmkernel->identityManager()->shadowIdentities().contains( newName ) ) {
KPIM::Identity & ident = item->identity();
ident.setIdentityName( newName );
emit changed(true);
@@ -739,7 +739,7 @@ static inline TQString uniqueName( const TQStringList & list,
{
int suffix = 1;
TQString result = name;
- while ( list.tqfind( result ) != list.end() ) {
+ while ( list.find( result ) != list.end() ) {
result = i18n("%1: name; %2: number appended to it to make it unique "
"among a list of names", "%1 %2")
.tqarg( name ).tqarg( suffix );
@@ -2057,7 +2057,7 @@ AppearancePageHeadersTab::AppearancePageHeadersTab( TQWidget * tqparent, const c
for ( int i = 0 ; i < numDateDisplayConfig ; i++ ) {
TQString buttonLabel = i18n(dateDisplayConfig[i].displayName);
- if ( buttonLabel.tqcontains("%1") )
+ if ( buttonLabel.contains("%1") )
buttonLabel = buttonLabel.tqarg( DateFormatter::formatCurrentDate( dateDisplayConfig[i].dateDisplay ) );
radio = new TQRadioButton( buttonLabel, mDateDisplay );
mDateDisplay->insert( radio, i );
@@ -2367,7 +2367,7 @@ void AppearancePage::ReaderTab::readCurrentFallbackCodec()
TQStringList::ConstIterator it( encodings.begin() );
TQStringList::ConstIterator end( encodings.end() );
TQString currentEncoding = GlobalSettings::self()->fallbackCharacterEncoding();
- currentEncoding = currentEncoding.tqreplace( "iso ", "iso-", false );
+ currentEncoding = currentEncoding.replace( "iso ", "iso-", false );
///kdDebug(5006) << "Looking for encoding: " << currentEncoding << endl;
int i = 0;
int indexOfLatin9 = 0;
@@ -3203,7 +3203,7 @@ ComposerPageSubjectTab::ComposerPageSubjectTab( TQWidget * tqparent, const char
connect( mReplyListEditor, TQT_SIGNAL( changed( void ) ),
this, TQT_SLOT( slotEmitChanged( void ) ) );
// row 2: "tqreplace [...]" check box:
mReplaceReplyPrefixCheck = new TQCheckBox(
GlobalSettings::self()->replaceReplyPrefixItem()->label(),
group, "kcfg_ReplaceReplyPrefix" );
@@ -3231,7 +3231,7 @@ ComposerPageSubjectTab::ComposerPageSubjectTab( TQWidget * tqparent, const char
connect( mForwardListEditor, TQT_SIGNAL( changed( void ) ),
this, TQT_SLOT( slotEmitChanged( void ) ) );
// row 3: "tqreplace [...]" check box:
mReplaceForwardPrefixCheck = new TQCheckBox(
GlobalSettings::self()->replaceForwardPrefixItem()->label(),
group, "kcfg_ReplaceForwardPrefix" );
@@ -3855,7 +3855,7 @@ SecurityPageGeneralTab::SecurityPageGeneralTab( TQWidget * tqparent, const char
mMDNGroup->insert( radio );
for ( int i = 0 ; i < mMDNGroup->count() ; ++i )
- TQWhatsThis::add( mMDNGroup->tqfind( i ), receiptWhatsThis );
+ TQWhatsThis::add( mMDNGroup->find( i ), receiptWhatsThis );
w = new TQWidget( hbox ); // spacer
hbox->setStretchFactor( w, 1 );
@@ -5051,7 +5051,7 @@ void MiscPage::GroupwareTab::doLoadFromGlobalSettings() {
KMAccount* selectedAccount = 0;
int accountId = GlobalSettings::self()->theIMAPResourceAccount();
if ( accountId )
- selectedAccount = kmkernel->acctMgr()->tqfind( accountId );
+ selectedAccount = kmkernel->acctMgr()->find( accountId );
else {
// Fallback: iterate over accounts to select folderId if found (as an inbox folder)
for( KMAccount *a = kmkernel->acctMgr()->first(); a!=0;
@@ -3203,7 +3203,7 @@ ComposerPageSubjectTab::ComposerPageSubjectTab( TQWidget * tqparent, const char
connect( mReplyListEditor, TQT_SIGNAL( changed( void ) ),
this, TQT_SLOT( slotEmitChanged( void ) ) );
- // row 2: "tqreplace [...]" check box:
+ // row 2: "replace [...]" check box:
mReplaceReplyPrefixCheck = new TQCheckBox(
GlobalSettings::self()->replaceReplyPrefixItem()->label(),
@@ -3231,7 +3231,7 @@ ComposerPageSubjectTab::ComposerPageSubjectTab( TQWidget * tqparent, const char
connect( mForwardListEditor, TQT_SIGNAL( changed( void ) ),
this, TQT_SLOT( slotEmitChanged( void ) ) );
- // row 3: "tqreplace [...]" check box:
+ // row 3: "replace [...]" check box:
mReplaceForwardPrefixCheck = new TQCheckBox(
GlobalSettings::self()->replaceForwardPrefixItem()->label(),